@@ -34,6 +34,9 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         if not os.path.exists('CapturedImages/sequenceImages/undistortRadioCalib/'):
             os.mkdir('CapturedImages/sequenceImages/undistortRadioCalib/radioCalibResults')
             
+        if not os.path.exists('CalibrationImages/DisplayRadiometric'):
+            os.mkdir('CalibrationImages/DisplayRadiometric')
+            
 
         
 
@@ -74,7 +77,7 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
 
 
     def calculateReflectivity(self):
-        imgPath = 'test.png'
+        imgPath = 'testImages/RadioDisplayTest.png'
         arr = self.calUpValue(imgPath)
 
         # img = cv2.imread(imgPath, cv2.IMREAD_GRAYSCALE)
@@ -163,6 +166,12 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         cv2.destroyAllWindows()
         cv2.waitKey(1)
         cv2.waitKey(1)
+        
+        window_name = 'projector'
+        cv2.namedWindow(window_name)
+        cv2.moveWindow(window_name, self.displayWidth, 0)  #self.displayWidth
+            
+        
         if not os.path.exists('CalibrationNumpyData/'):
             os.mkdir('CalibrationNumpyData/')
         if not os.path.exists('CalibrationNumpyData/DisplayRadiometric/'):
@@ -171,13 +180,13 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         for i in range(self.NumPatterns):
             if i % 10 == 0:
                 print('picture taken:' + str(i))
+
             cur_img = self.patterns[... ,i]
-            window_name = 'projector' + str(i)
-            cv2.namedWindow(window_name)
-            cv2.moveWindow(window_name, self.displayWidth, 0)  #self.displayWidth
             cv2.imshow(window_name, self.patterns[..., i].astype(np.uint8))
             cv2.waitKey(40)
             self.camera.getImage(name = 'DisplayRadiometric/'+str(i), calibration=True)
+            
+        print('Capture Complete! Numpy data viewable at CalibrationImages/DisplayRadiometric/')    
         cv2.waitKey(1000)
         cv2.destroyAllWindows()
         cv2.waitKey(1)
